# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKThresholdingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkKappaSigmaThresholdImageFilterPython
else:
    import _itkKappaSigmaThresholdImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImagePython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkKappaSigmaThresholdImageFilterIF2ISS2_New():
    return itkKappaSigmaThresholdImageFilterIF2ISS2.New()

class itkKappaSigmaThresholdImageFilterIF2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterIF2ISS2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterIF2ISS2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterIF2ISS2

        Create a new object of the class itkKappaSigmaThresholdImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterIF2ISS2 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2ISS2_swigregister(itkKappaSigmaThresholdImageFilterIF2ISS2)

def itkKappaSigmaThresholdImageFilterIF2IUC2_New():
    return itkKappaSigmaThresholdImageFilterIF2IUC2.New()

class itkKappaSigmaThresholdImageFilterIF2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterIF2IUC2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterIF2IUC2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterIF2IUC2

        Create a new object of the class itkKappaSigmaThresholdImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterIF2IUC2 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF2IUC2_swigregister(itkKappaSigmaThresholdImageFilterIF2IUC2)

def itkKappaSigmaThresholdImageFilterIF3ISS3_New():
    return itkKappaSigmaThresholdImageFilterIF3ISS3.New()

class itkKappaSigmaThresholdImageFilterIF3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterIF3ISS3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterIF3ISS3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterIF3ISS3

        Create a new object of the class itkKappaSigmaThresholdImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterIF3ISS3 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3ISS3_swigregister(itkKappaSigmaThresholdImageFilterIF3ISS3)

def itkKappaSigmaThresholdImageFilterIF3IUC3_New():
    return itkKappaSigmaThresholdImageFilterIF3IUC3.New()

class itkKappaSigmaThresholdImageFilterIF3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterIF3IUC3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterIF3IUC3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterIF3IUC3

        Create a new object of the class itkKappaSigmaThresholdImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterIF3IUC3 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIF3IUC3_swigregister(itkKappaSigmaThresholdImageFilterIF3IUC3)

def itkKappaSigmaThresholdImageFilterISS2ISS2_New():
    return itkKappaSigmaThresholdImageFilterISS2ISS2.New()

class itkKappaSigmaThresholdImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterISS2ISS2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterISS2ISS2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterISS2ISS2

        Create a new object of the class itkKappaSigmaThresholdImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterISS2ISS2 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2ISS2_swigregister(itkKappaSigmaThresholdImageFilterISS2ISS2)

def itkKappaSigmaThresholdImageFilterISS2IUC2_New():
    return itkKappaSigmaThresholdImageFilterISS2IUC2.New()

class itkKappaSigmaThresholdImageFilterISS2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterISS2IUC2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterISS2IUC2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterISS2IUC2

        Create a new object of the class itkKappaSigmaThresholdImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterISS2IUC2 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS2IUC2_swigregister(itkKappaSigmaThresholdImageFilterISS2IUC2)

def itkKappaSigmaThresholdImageFilterISS3ISS3_New():
    return itkKappaSigmaThresholdImageFilterISS3ISS3.New()

class itkKappaSigmaThresholdImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterISS3ISS3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterISS3ISS3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterISS3ISS3

        Create a new object of the class itkKappaSigmaThresholdImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterISS3ISS3 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3ISS3_swigregister(itkKappaSigmaThresholdImageFilterISS3ISS3)

def itkKappaSigmaThresholdImageFilterISS3IUC3_New():
    return itkKappaSigmaThresholdImageFilterISS3IUC3.New()

class itkKappaSigmaThresholdImageFilterISS3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterISS3IUC3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterISS3IUC3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterISS3IUC3

        Create a new object of the class itkKappaSigmaThresholdImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterISS3IUC3 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterISS3IUC3_swigregister(itkKappaSigmaThresholdImageFilterISS3IUC3)

def itkKappaSigmaThresholdImageFilterIUC2ISS2_New():
    return itkKappaSigmaThresholdImageFilterIUC2ISS2.New()

class itkKappaSigmaThresholdImageFilterIUC2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterIUC2ISS2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterIUC2ISS2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterIUC2ISS2

        Create a new object of the class itkKappaSigmaThresholdImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterIUC2ISS2 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2ISS2_swigregister(itkKappaSigmaThresholdImageFilterIUC2ISS2)

def itkKappaSigmaThresholdImageFilterIUC2IUC2_New():
    return itkKappaSigmaThresholdImageFilterIUC2IUC2.New()

class itkKappaSigmaThresholdImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterIUC2IUC2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterIUC2IUC2_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterIUC2IUC2

        Create a new object of the class itkKappaSigmaThresholdImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterIUC2IUC2 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC2IUC2_swigregister(itkKappaSigmaThresholdImageFilterIUC2IUC2)

def itkKappaSigmaThresholdImageFilterIUC3ISS3_New():
    return itkKappaSigmaThresholdImageFilterIUC3ISS3.New()

class itkKappaSigmaThresholdImageFilterIUC3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterIUC3ISS3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterIUC3ISS3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterIUC3ISS3

        Create a new object of the class itkKappaSigmaThresholdImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterIUC3ISS3 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3ISS3_swigregister(itkKappaSigmaThresholdImageFilterIUC3ISS3)

def itkKappaSigmaThresholdImageFilterIUC3IUC3_New():
    return itkKappaSigmaThresholdImageFilterIUC3IUC3.New()

class itkKappaSigmaThresholdImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkKappaSigmaThresholdImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKappaSigmaThresholdImageFilterIUC3IUC3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKappaSigmaThresholdImageFilterIUC3IUC3_Pointer"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_Clone(self)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_GetInsideValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_GetThreshold(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_GetMaskValue(self)

    def SetSigmaFactor(self, _arg):
        r"""
        SetSigmaFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_SetSigmaFactor(self, _arg)

    def GetSigmaFactor(self):
        r"""GetSigmaFactor(self) -> double"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_GetSigmaFactor(self)

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_GetNumberOfIterations(self)
    OutputComparableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_OutputComparableCheck
    
    OutputOStreamWritableCheck = _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_OutputOStreamWritableCheck
    

    def SetMaskImage(self, input):
        r"""
        SetMaskImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_SetMaskImage(self, input)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_SetInput2(self, input)
    __swig_destroy__ = _itkKappaSigmaThresholdImageFilterPython.delete_itkKappaSigmaThresholdImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKappaSigmaThresholdImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKappaSigmaThresholdImageFilterIUC3IUC3

        Create a new object of the class itkKappaSigmaThresholdImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKappaSigmaThresholdImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKappaSigmaThresholdImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKappaSigmaThresholdImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKappaSigmaThresholdImageFilterIUC3IUC3 in _itkKappaSigmaThresholdImageFilterPython:
_itkKappaSigmaThresholdImageFilterPython.itkKappaSigmaThresholdImageFilterIUC3IUC3_swigregister(itkKappaSigmaThresholdImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def kappa_sigma_threshold_image_filter(*args: itkt.ImageLike,  outside_value: int=..., inside_value: int=..., mask_value: int=..., sigma_factor: float=..., number_of_iterations: int=..., mask_image: itkt.Image=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for KappaSigmaThresholdImageFilter"""
    import itk

    kwarg_typehints = { 'outside_value':outside_value,'inside_value':inside_value,'mask_value':mask_value,'sigma_factor':sigma_factor,'number_of_iterations':number_of_iterations,'mask_image':mask_image }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.KappaSigmaThresholdImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def kappa_sigma_threshold_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKThresholding.KappaSigmaThresholdImageFilter
    kappa_sigma_threshold_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    kappa_sigma_threshold_image_filter.__doc__ = filter_object.__doc__



